@@ -66,13 +66,16 @@ class DiscordService(managed_service.ManagedService):
         super().__init__()
         self.client = None
         self.log_rollup = {name: list() for name in config.get_server_names()}
-        start_date = datetime.datetime.now().replace(year=1984)
+        start_date = datetime.datetime.now().replace(minute=max(0, datetime.datetime.now().minute - 3))
         self.last_log_time = {name: start_date for name in config.get_server_names()}
         self.last_player_count_update = {name: start_date for name in config.get_server_names()}
         self.player_counts = {name: '' for name in config.get_server_names()}
 
     async def stop(self):
         await self.client.close()
+        sleep_length = 30
+        log.info(f'sleeping for {sleep_length} seconds')
+        await asyncio.sleep(sleep_length)
         await super().stop()
 
     async def service(self):
@@ -126,7 +129,7 @@ class DiscordService(managed_service.ManagedService):
                 queue=message.queue,
                 time=message.time)
             if self.player_counts[message.server_name] != player_count_string:
-                if datetime.timedelta(minutes=5) < \
+                if datetime.timedelta(minutes=6) < \
                         datetime.datetime.now() - self.last_player_count_update[message.server_name]:
                     # Rate limit is triggered when updating a channel name too often, so that's why we
                     # put a hard limit on how often the player count channel gets updated
